@@ -25,7 +25,6 @@
 
 #include "suricata-common.h"
 #include "threads.h"
-#include "debug.h"
 #include "decode.h"
 
 #include "detect.h"
@@ -98,19 +97,21 @@ static void ConfigApplyTx(Flow *f,
         if (txd) {
             SCLogDebug("tx %p txd %p: log_flags %x", tx, txd, txd->config.log_flags);
             txd->config.log_flags |= BIT_U8(config->type);
+
+            uint64_t unidir = ((AppLayerParserGetTxDetectFlags(txd, STREAM_TOSERVER) |
+                                       AppLayerParserGetTxDetectFlags(txd, STREAM_TOCLIENT)) &
+                                      APP_LAYER_TX_SKIP_INSPECT_FLAG) != 0;
+            if (unidir) {
+                SCLogDebug("handle unidir tx");
+                AppLayerTxConfig req;
+                memset(&req, 0, sizeof(req));
+                req.log_flags = BIT_U8(config->type);
+                AppLayerParserApplyTxConfig(
+                        f->proto, f->alproto, f->alstate, tx, CONFIG_ACTION_SET, req);
+            }
         } else {
             SCLogDebug("no tx data");
         }
-
-        if (AppLayerParserGetOptionFlags(f->protomap, f->alproto) &
-                APP_LAYER_PARSER_OPT_UNIDIR_TXS) {
-            SCLogDebug("handle unidir tx");
-            AppLayerTxConfig req;
-            memset(&req, 0, sizeof(req));
-            req.log_flags = BIT_U8(config->type);
-            AppLayerParserApplyTxConfig(f->proto, f->alproto, f->alstate, tx,
-                    CONFIG_ACTION_SET, req);
-        }
     } else {
         SCLogDebug("no tx");
     }
@@ -170,24 +171,24 @@ static int DetectConfigSetup (DetectEngineCtx *de_ctx, Signature *s, const char
 
     DetectConfigData *fd = NULL;
     SigMatch *sm = NULL;
-#define MAX_SUBSTRINGS 30
-    int ret = 0, res = 0;
-    int ov[MAX_SUBSTRINGS];
+    int res = 0;
+    size_t pcre2len;
 #if 0
     /* filestore and bypass keywords can't work together */
     if (s->flags & SIG_FLAG_BYPASS) {
-        SCLogError(SC_ERR_CONFLICTING_RULE_KEYWORDS,
+        SCLogError(
                    "filestore can't work with bypass keyword");
         return -1;
     }
 #endif
+    pcre2_match_data *match = NULL;
     sm = SigMatchAlloc();
     if (sm == NULL)
         goto error;
     sm->type = DETECT_CONFIG;
 
     if (str == NULL || strlen(str) == 0) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "config keywords need arguments");
+        SCLogError("config keywords need arguments");
         goto error;
     }
     char subsys[32];
@@ -198,79 +199,85 @@ static int DetectConfigSetup (DetectEngineCtx *de_ctx, Signature *s, const char
     char scopeval[32];
     SCLogDebug("str %s", str);
 
-    ret = DetectParsePcreExec(&parse_regex,  str, 0, 0, ov, MAX_SUBSTRINGS);
+    int ret = DetectParsePcreExec(&parse_regex, &match, str, 0, 0);
     if (ret != 7) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "config is rather picky at this time");
+        SCLogError("config is rather picky at this time");
         goto error;
     }
-    res = pcre_copy_substring((char *)str, ov, MAX_SUBSTRINGS, 1, subsys, sizeof(subsys));
+    pcre2len = sizeof(subsys);
+    res = pcre2_substring_copy_bynumber(match, 1, (PCRE2_UCHAR8 *)subsys, &pcre2len);
     if (res < 0) {
-        SCLogError(SC_ERR_PCRE_COPY_SUBSTRING, "pcre_copy_substring failed");
+        SCLogError("pcre2_substring_copy_bynumber failed");
         goto error;
     }
 
     if (strcmp(subsys, "logging") != 0) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "only 'logging' supported at this time");
+        SCLogError("only 'logging' supported at this time");
         goto error;
     }
     SCLogDebug("subsys %s", subsys);
 
-    res = pcre_copy_substring((char *)str, ov, MAX_SUBSTRINGS, 2, state, sizeof(state));
+    pcre2len = sizeof(state);
+    res = pcre2_substring_copy_bynumber(match, 2, (PCRE2_UCHAR8 *)state, &pcre2len);
     if (res < 0) {
-        SCLogError(SC_ERR_PCRE_COPY_SUBSTRING, "pcre_copy_substring failed");
+        SCLogError("pcre2_substring_copy_bynumber failed");
         goto error;
     }
 
     if (strcmp(state, "disable") != 0) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "only 'disable' supported at this time");
+        SCLogError("only 'disable' supported at this time");
         goto error;
     }
     SCLogDebug("state %s", state);
 
-    res = pcre_copy_substring((char *)str, ov, MAX_SUBSTRINGS, 3, type, sizeof(type));
+    pcre2len = sizeof(type);
+    res = pcre2_substring_copy_bynumber(match, 3, (PCRE2_UCHAR8 *)type, &pcre2len);
     if (res < 0) {
-        SCLogError(SC_ERR_PCRE_COPY_SUBSTRING, "pcre_copy_substring failed");
+        SCLogError("pcre2_substring_copy_bynumber failed");
         goto error;
     }
 
     if (strcmp(type, "type") != 0) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "only 'type' supported at this time");
+        SCLogError("only 'type' supported at this time");
         goto error;
     }
     SCLogDebug("type %s", type);
 
-    res = pcre_copy_substring((char *)str, ov, MAX_SUBSTRINGS, 4, typeval, sizeof(typeval));
+    pcre2len = sizeof(typeval);
+    res = pcre2_substring_copy_bynumber(match, 4, (PCRE2_UCHAR8 *)typeval, &pcre2len);
     if (res < 0) {
-        SCLogError(SC_ERR_PCRE_COPY_SUBSTRING, "pcre_copy_substring failed");
+        SCLogError("pcre2_substring_copy_bynumber failed");
         goto error;
     }
 
     if (!(strcmp(typeval, "tx") == 0 ||strcmp(typeval, "flow") == 0)) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "only 'tx' and 'flow' supported at this time");
+        SCLogError("only 'tx' and 'flow' supported at this time");
         goto error;
     }
     SCLogDebug("typeval %s", typeval);
 
-    res = pcre_copy_substring((char *)str, ov, MAX_SUBSTRINGS, 5, scope, sizeof(scope));
+    pcre2len = sizeof(scope);
+    res = pcre2_substring_copy_bynumber(match, 5, (PCRE2_UCHAR8 *)scope, &pcre2len);
     if (res < 0) {
-        SCLogError(SC_ERR_PCRE_COPY_SUBSTRING, "pcre_copy_substring failed");
+        SCLogError("pcre2_substring_copy_bynumber failed");
         goto error;
     }
 
     if (strcmp(scope, "scope") != 0) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "only 'scope' supported at this time");
+        SCLogError("only 'scope' supported at this time");
         goto error;
     }
     SCLogDebug("scope %s", scope);
 
-    res = pcre_copy_substring((char *)str, ov, MAX_SUBSTRINGS, 6, scopeval, sizeof(scopeval));
+    pcre2len = sizeof(scopeval);
+    res = pcre2_substring_copy_bynumber(match, 6, (PCRE2_UCHAR8 *)scopeval, &pcre2len);
     if (res < 0) {
-        SCLogError(SC_ERR_PCRE_COPY_SUBSTRING, "pcre_copy_substring failed");
+        SCLogError("pcre2_substring_copy_bynumber failed");
         goto error;
     }
 
     if (!(strcmp(scopeval, "tx") == 0 ||strcmp(scopeval, "flow") == 0)) {
-        SCLogError(SC_ERR_INVALID_RULE_ARGUMENT, "only 'tx' and 'flow' supported at this time");
+        SCLogError("only 'tx' and 'flow' supported at this time");
         goto error;
     }
     SCLogDebug("scopeval %s", scopeval);
@@ -293,9 +300,13 @@ static int DetectConfigSetup (DetectEngineCtx *de_ctx, Signature *s, const char
     sm->ctx = (SigMatchCtx*)fd;
     SigMatchAppendSMToList(s, sm, DETECT_SM_LIST_POSTMATCH);
 
+    pcre2_match_data_free(match);
     return 0;
 
 error:
+    if (match) {
+        pcre2_match_data_free(match);
+    }
     if (sm != NULL)
         SCFree(sm);
     return -1;
