@@ -26,7 +26,6 @@
  */
 
 #include "suricata-common.h"
-#include "debug.h"
 #include "decode.h"
 #include "detect.h"
 
@@ -44,7 +43,7 @@
 
 static int DetectGeoipSetupNoSupport (DetectEngineCtx *a, Signature *b, const char *c)
 {
-    SCLogError(SC_ERR_NO_GEOIP_SUPPORT, "no GeoIP support built in, needed for geoip keyword");
+    SCLogError("no GeoIP support built in, needed for geoip keyword");
     return -1;
 }
 
@@ -104,7 +103,7 @@ static bool InitGeolocationEngine(DetectGeoipData *geoipdata)
     (void)ConfGet("geoip-database", &filename);
 
     if (filename == NULL) {
-        SCLogWarning(SC_ERR_INVALID_ARGUMENT, "Unable to locate a GeoIP2"
+        SCLogWarning("Unable to locate a GeoIP2"
                      "database filename in YAML conf.  GeoIP rule matching "
                      "is disabled.");
         geoipdata->mmdb_status = MMDB_FILE_OPEN_ERROR;
@@ -119,9 +118,9 @@ static bool InitGeolocationEngine(DetectGeoipData *geoipdata)
         return true;
     }
 
-    SCLogWarning(SC_ERR_INVALID_ARGUMENT, "Failed to open GeoIP2 database: %s. "
-                 "Error was: %s.  GeoIP rule matching is disabled.", filename,
-                 MMDB_strerror(status));
+    SCLogWarning("Failed to open GeoIP2 database: %s. "
+                 "Error was: %s.  GeoIP rule matching is disabled.",
+            filename, MMDB_strerror(status));
     geoipdata->mmdb_status = status;
     return false;
 }
@@ -352,7 +351,7 @@ static DetectGeoipData *DetectGeoipDataParse (DetectEngineCtx *de_ctx, const cha
                 }
 
                 if (geoipdata->nlocations >= GEOOPTION_MAXLOCATIONS) {
-                    SCLogError(SC_ERR_INVALID_ARGUMENT, "too many arguements for geoip keyword");
+                    SCLogError("too many arguments for geoip keyword");
                     goto error;
                 }
 
@@ -469,11 +468,11 @@ static int GeoipParseTest(const char *rule, int ncountries, const char **countri
     FAIL_IF(de_ctx->sig_list == NULL);
 
     s = de_ctx->sig_list;
-    FAIL_IF(s->sm_lists_tail[DETECT_SM_LIST_MATCH] == NULL);
+    FAIL_IF(s->init_data->smlists_tail[DETECT_SM_LIST_MATCH] == NULL);
 
-    FAIL_IF(s->sm_lists_tail[DETECT_SM_LIST_MATCH]->type != DETECT_GEOIP);
+    FAIL_IF(s->init_data->smlists_tail[DETECT_SM_LIST_MATCH]->type != DETECT_GEOIP);
 
-    data = (DetectGeoipData *)s->sm_lists_tail[DETECT_SM_LIST_MATCH]->ctx;
+    data = (DetectGeoipData *)s->init_data->smlists_tail[DETECT_SM_LIST_MATCH]->ctx;
     FAIL_IF(data->flags != flags);
 
     FAIL_IF(data->nlocations!=ncountries);
@@ -551,4 +550,4 @@ static void DetectGeoipRegisterTests(void)
     UtRegisterTest("GeoipParseTest07", GeoipParseTest07);
 }
 #endif /* UNITTESTS */
-#endif /* HAVE_GEOIP */
\ No newline at end of file
+#endif /* HAVE_GEOIP */
