@@ -23,11 +23,11 @@
 
 #include "suricata-common.h"
 #include "threads.h"
-#include "debug.h"
 #include "decode.h"
 
 #include "detect.h"
 #include "detect-parse.h"
+#include "detect-content.h"
 
 #include "detect-engine.h"
 #include "detect-engine-mpm.h"
@@ -97,7 +97,7 @@ static InspectionBuffer *GetSshData(DetectEngineThreadCtx *det_ctx,
  */
 static int DetectSshHasshServerSetup(DetectEngineCtx *de_ctx, Signature *s, const char *arg)
 {
-    if (DetectBufferSetActiveList(s, g_ssh_hassh_buffer_id) < 0)
+    if (DetectBufferSetActiveList(de_ctx, s, g_ssh_hassh_buffer_id) < 0)
         return -1;
 
     if (DetectSignatureSetAppProto(s, ALPROTO_SSH) < 0)
@@ -109,7 +109,7 @@ static int DetectSshHasshServerSetup(DetectEngineCtx *de_ctx, Signature *s, cons
     /* Check if Hassh is disabled */
     if (!RunmodeIsUnittests() && !rs_ssh_hassh_is_enabled()) {
         if (!SigMatchSilentErrorEnabled(de_ctx, DETECT_AL_SSH_HASSH_SERVER)) {
-            SCLogError(SC_WARN_HASSH_DISABLED, "hassh support is not enabled");
+            SCLogError("hassh support is not enabled");
         }
         return -2;
     }
@@ -118,70 +118,70 @@ static int DetectSshHasshServerSetup(DetectEngineCtx *de_ctx, Signature *s, cons
 
 }
 
-
-static _Bool DetectSshHasshServerHashValidateCallback(const Signature *s,
-                                              const char **sigerror)
+static bool DetectSshHasshServerHashValidateCallback(const Signature *s, const char **sigerror)
 {
-    const SigMatch *sm = s->init_data->smlists[g_ssh_hassh_buffer_id];
-    for ( ; sm != NULL; sm = sm->next)
-    {
-        if (sm->type != DETECT_CONTENT)
+    for (uint32_t x = 0; x < s->init_data->buffer_index; x++) {
+        if (s->init_data->buffers[x].id != (uint32_t)g_ssh_hassh_buffer_id)
             continue;
+        const SigMatch *sm = s->init_data->buffers[x].head;
+        for (; sm != NULL; sm = sm->next) {
+            if (sm->type != DETECT_CONTENT)
+                continue;
 
-        const DetectContentData *cd = (DetectContentData *)sm->ctx;
+            const DetectContentData *cd = (DetectContentData *)sm->ctx;
 
-        if (cd->flags & DETECT_CONTENT_NOCASE) {
-            *sigerror = "ssh.hassh.server should not be used together with "
-                        "nocase, since the rule is automatically "
-                        "lowercased anyway which makes nocase redundant.";
-            SCLogWarning(SC_WARN_POOR_RULE, "rule %u: %s", s->id, *sigerror);
-        }
+            if (cd->flags & DETECT_CONTENT_NOCASE) {
+                *sigerror = "ssh.hassh.server should not be used together with "
+                            "nocase, since the rule is automatically "
+                            "lowercased anyway which makes nocase redundant.";
+                SCLogWarning("rule %u: %s", s->id, *sigerror);
+            }
 
-        if (cd->content_len != 32)
-        {
-            *sigerror = "Invalid length of the specified ssh.hassh.server (should "
-                        "be 32 characters long). This rule will therefore "
-                        "never match.";
-            SCLogWarning(SC_WARN_POOR_RULE,  "rule %u: %s", s->id, *sigerror);
-            return FALSE;
-        }
-        for (size_t i = 0; i < cd->content_len; ++i)
-        {
-            if(!isxdigit(cd->content[i])) 
-            {
-                *sigerror = "Invalid ssh.hassh.server string (should be string of hexademical characters)."
-                            "This rule will therefore never match.";
-                SCLogWarning(SC_WARN_POOR_RULE,  "rule %u: %s", s->id, *sigerror);
-                return FALSE;
+            if (cd->content_len != 32) {
+                *sigerror = "Invalid length of the specified ssh.hassh.server (should "
+                            "be 32 characters long). This rule will therefore "
+                            "never match.";
+                SCLogWarning("rule %u: %s", s->id, *sigerror);
+                return false;
+            }
+            for (size_t i = 0; i < cd->content_len; ++i) {
+                if (!isxdigit(cd->content[i])) {
+                    *sigerror = "Invalid ssh.hassh.server string (should be string of hexadecimal "
+                                "characters)."
+                                "This rule will therefore never match.";
+                    SCLogWarning("rule %u: %s", s->id, *sigerror);
+                    return false;
+                }
             }
         }
     }
-
-    return TRUE;
+    return true;
 }
 
 static void DetectSshHasshServerHashSetupCallback(const DetectEngineCtx *de_ctx,
                                           Signature *s)
 {
-    SigMatch *sm = s->init_data->smlists[g_ssh_hassh_buffer_id];
-    for ( ; sm != NULL; sm = sm->next)
-    {
-        if (sm->type != DETECT_CONTENT)
+    for (uint32_t x = 0; x < s->init_data->buffer_index; x++) {
+        if (s->init_data->buffers[x].id != (uint32_t)g_ssh_hassh_buffer_id)
             continue;
+        SigMatch *sm = s->init_data->buffers[x].head;
+        for (; sm != NULL; sm = sm->next) {
+            if (sm->type != DETECT_CONTENT)
+                continue;
 
-        DetectContentData *cd = (DetectContentData *)sm->ctx;
+            DetectContentData *cd = (DetectContentData *)sm->ctx;
 
-        uint32_t u;
-        for (u = 0; u < cd->content_len; u++)
-        {
-            if (isupper(cd->content[u])) {
-                cd->content[u] = tolower(cd->content[u]);
+            uint32_t u;
+            for (u = 0; u < cd->content_len; u++) {
+                if (isupper(cd->content[u])) {
+                    cd->content[u] = u8_tolower(cd->content[u]);
+                }
             }
-        }
 
-        SpmDestroyCtx(cd->spm_ctx);
-        cd->spm_ctx = SpmInitCtx(cd->content, cd->content_len, 1,
-        		de_ctx->spm_global_thread_ctx);
+            SpmDestroyCtx(cd->spm_ctx);
+            cd->spm_ctx =
+                    SpmInitCtx(cd->content, cd->content_len, 1, de_ctx->spm_global_thread_ctx);
+        }
     }
 }
 
