@@ -24,9 +24,6 @@
 #ifndef __DETECT_THRESHOLD_H__
 #define __DETECT_THRESHOLD_H__
 
-#include "decode-events.h"
-#include "decode-ipv4.h"
-#include "decode-tcp.h"
 
 #define TYPE_LIMIT     1
 #define TYPE_BOTH      2
@@ -75,7 +72,7 @@ typedef struct DetectThresholdEntry_ {
     uint32_t current_count; /**< Var for count control */
     int track;          /**< Track type: by_src, by_src */
 
-    struct timeval tv1;     /**< Var for time control */
+    SCTime_t tv1; /**< Var for time control */
     struct DetectThresholdEntry_ *next;
 } DetectThresholdEntry;
 
