@@ -24,9 +24,6 @@
 #ifndef __DETECT_TLS_SNI_H__
 #define __DETECT_TLS_SNI_H__
 
-#include "app-layer-ssl.h"
-
 void DetectTlsSniRegister(void);
-uint32_t DetectTlsSniInspectMpm(DetectEngineThreadCtx *det_ctx, SSLState *ssl_state);
 
 #endif /* __DETECT_TLS_SNI_H__ */
